@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Data;
-$Net::Whois::Raw::Data::VERSION = '2.95';
+$Net::Whois::Raw::Data::VERSION = '2.96';
 # ABSTRACT: Config for Net::Whois::Raw.
 
 use utf8;
@@ -774,6 +774,8 @@ our %servers = qw(
     BIZ.NS      whois.biz
     NAME.NS     whois.nic.name
     VIP         whois.nic.vip
+    GAME        whois.nic.game
+    PROMO       whois.nic.promo
 );
 
 
@@ -2689,7 +2691,7 @@ Net::Whois::Raw::Data - Config for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.95
+version 2.96
 
 =head1 AUTHOR
 
